#
# spec file for package conglomerate
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           conglomerate
BuildRequires:  enchant-devel
BuildRequires:  fdupes
BuildRequires:  gtk-doc
BuildRequires:  gtksourceview18-devel
BuildRequires:  intltool
BuildRequires:  libglade2-devel
BuildRequires:  libgnomeprintui-devel
BuildRequires:  libgnomeui-devel
BuildRequires:  libtool
BuildRequires:  libwnck-devel
BuildRequires:  libxslt-devel
BuildRequires:  perl-XML-Parser
BuildRequires:  scrollkeeper
BuildRequires:  sgml-skel
BuildRequires:  shared-mime-info
BuildRequires:  translation-update-upstream
BuildRequires:  update-desktop-files
Summary:        XML Editor for GNOME
License:        GPL-2.0+
Group:          Productivity/Publishing/XML
Version:        0.9.1
Release:        311.43
Recommends:     %{name}-lang
Url:            http://www.conglomerate.org/
Source0:        %{name}-%{version}.tar.bz2
Patch:          conglomerate-desktop.patch
Patch1:         conglomerate-dist.patch
Patch2:         conglomerate-readme-xds.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%gconf_schemas_prereq

%description
Conglomerate is a user-friendly XML editor for DocBook and other
document types. It aims to hide the complexity and jargon of XML behind
a friendly GUI.

%package doc
Summary:        Documentation for Conglomerate
Group:          Productivity/Publishing/XML
Requires:       %{name} = %{version}

%description doc
This package contains the documentation for Conglomerate, a
user-friendly XML editor for DocBook and other document types.

%lang_package
%prep
%setup -q
rename no nb po/no.*
sed -i "/^ALL_LINGUAS/s/ no / nb /" configure.in
%patch1
rm data/conglomerate.keys data/conglomerate.desktop data/conglomerate.schemas
translation-update-upstream
%patch -p 1
%patch2

%build
# - Add enchant and enchant-devel to neededforbuild.
# for the moment do not enable: enchant enchant-devel
# needed for conglomerate-0.9.1:
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
autoreconf -f -i
intltoolize --force
# FIXME: GTKDOC_CFLAGS:
# Silently ignored compilation of uninstalled gtk-doc scanners without RPM_OPT_FLAGS.
%configure\
	--disable-scrollkeeper\
	--disable-schemas-install\
	--enable-printing
make %{?jobs:-j%jobs}

%install
%makeinstall
DESTDIR=$RPM_BUILD_ROOT mime-info-to-mime
%suse_update_desktop_file -N "Conglomerate" %name Utility TextEditor
# Change sr@Latn to sr@latin
mv %{buildroot}%{_datadir}/locale/sr@Latn %{buildroot}%{_datadir}/locale/sr@latin
%find_lang %{name} %{?no_lang_C}
%find_gconf_schemas
cat %{name}.schemas_list >%{name}.lst
rm -r $RPM_BUILD_ROOT%{_datadir}/mime-info $RPM_BUILD_ROOT%{_datadir}/application-registry
%fdupes $RPM_BUILD_ROOT

%clean
rm -rf $RPM_BUILD_ROOT

%pre -f %{name}.schemas_pre

%post
%if 0%{?suse_version} > 1130
%desktop_database_post
%mime_database_post
%else
if test -x usr/bin/update-mime-database ; then
  usr/bin/update-mime-database usr/share/mime >/dev/null
fi
%endif

%posttrans -f %{name}.schemas_posttrans

%postun
%if 0%{?suse_version} > 1130
%desktop_database_postun
%mime_database_postun
%else
if test -x usr/bin/update-mime-database ; then
  usr/bin/update-mime-database usr/share/mime >/dev/null
fi
%endif

%preun -f %{name}.schemas_preun

%files -f %{name}.lst
%defattr(-, root, root)
%dir %{_datadir}/gnome/
%dir %{_datadir}/gnome/help/
%dir %{_datadir}/gnome/help/%{name}/
%doc %{_datadir}/gnome/help/%{name}/C/
%dir %{_datadir}/omf/
%dir %{_datadir}/omf/%{name}/
%doc %{_datadir}/omf/%{name}/%{name}-C.omf
%{_bindir}/*
%{_datadir}/applications/*.desktop
%{_datadir}/%{name}
%{_datadir}/pixmaps/*
%{_datadir}/mime/packages/*.xml

%files lang -f %{name}.lang

%files doc
%defattr(-, root, root)
%{_datadir}/gtk-doc/html/conglomerate

%changelog
* Wed Apr  8 2015 dimstar@opensuse.org
- Update conglomerate-desktop.patch: let's reference the 32x32
  icon, which happens to also be shipped.
* Wed May 23 2012 vuntz@opensuse.org
- Drop gnutls-devel BuildRequires: it's not needed.
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
- Added source file for conglomerate.schemas, removed generated
  files from "make dist" to ensure that latest translation files
  are used in the build.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Sat Jan 31 2009 vuntz@novell.com
- Use sr@latin instead of sr@Latn.
* Thu Oct 16 2008 maw@novell.com
- Run intltoolize.
* Thu Nov  1 2007 sbrabec@suse.cz
- Build with gtksourceview18.
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed bogus dependency on mDNSResponder.
* Tue Aug 28 2007 stbinner@suse.de
- fix .desktop file: don't repeat GenericName content within Name
* Mon Aug  6 2007 maw@suse.de
- Split out a -lang subpackage
- Use %%fdupes.
* Wed Mar  7 2007 sbrabec@suse.cz
- Created -doc subpackage (#248813).
* Thu Jan  4 2007 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Wed Aug  2 2006 danw@suse.de
- intltoolize before autoreconf'ing to avoid version skew between
  configure macros and po/Makefile.in.in
* Fri Mar 31 2006 danw@suse.de
- Fix a bug in one of its XML support files that causes a warning
  at startup. #155949
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Aug  4 2005 sbrabec@suse.cz
- Updated to version 0.9.1.
* Thu Apr 14 2005 sbrabec@suse.cz
- Added audiofile-devel to neededforbuild.
* Fri Feb 18 2005 sbrabec@suse.cz
- Updated to version 0.9.0.
* Tue Feb  1 2005 meissner@suse.de
- 0 -> NULL in 2 gtk calls.
* Mon Nov 22 2004 ke@suse.de
- Fix desktop file.
* Fri Nov  5 2004 ke@suse.de
- Update to version 0.7.16.
- Drop obsolete patches.
* Thu Oct 28 2004 ke@suse.de
- Update to version 0.7.15:
  * Update and new translations.
  * Enhancements: Allow to add arbitrary XML elements, better namespace
    support, support CDATA section, show XPath in the status line, speedup
    by disabling some overzealous internal self-testing, etc.
  * Many bug fixes (various memory leaks, i18n work, improvements to the
    example files, etc.).
- Stop supplying fo-*.c files.
- Remove expat from neededforbuild.
* Tue Oct 19 2004 ke@suse.de
- Rename 'no' locale directory to 'nb' [#27748].
* Tue Oct 12 2004 ro@suse.de
- added libgpg-error, libgcrypt to neededforbuild
* Mon Sep 13 2004 ke@suse.de
- Drop obsolete docs patch; reported by Christian Meyer [#45060].
- conglomerate-0.7.14-desktop.patch: Fix Catagories statement to make it
  appear in the Gnome menue system.
* Tue Sep  7 2004 sbrabec@suse.cz
- Fixed mime info and generated shared mime info.
* Thu Jun 24 2004 ke@suse.de
- Update to version 0.7.14.
* Tue Jun 22 2004 ke@suse.de
- Update to version 0.7.13; many a lot enhancements and fixes.
- Add missing fo-*.c files from CVS.
- Build the docs, but disable parts of them.
* Tue May 25 2004 ke@suse.de
- Remove libgtop-devel form neededforbuild.
* Fri May 21 2004 ke@suse.de
- Fix gconf schema installation (thanks to Stanislav Brabec).
* Wed Mar 17 2004 sbrabec@suse.cz
- Fixed scrollkeeper calling conventions (#36215).
* Fri Feb 20 2004 sbrabec@suse.cz
- Fixed names of GNOME2 packages.
* Thu Feb 19 2004 ke@suse.de
- Update to version 0.7.12.
- Also call scrollkeeper-update at update time.
* Mon Feb 16 2004 ke@suse.de
- Call scrollkeeper-update as needed.
- PreReq: scrollkeeper.
* Thu Feb  5 2004 ke@suse.de
- Update to version 0.7.11.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Thu Jan  8 2004 ke@suse.de
- Update to version 0.7.10.
* Wed Dec 17 2003 ke@suse.de
- Update to version 0.7.7.
- Adjust file list.
* Mon Nov  3 2003 ke@suse.de
- Update to version 0.7.6.
* Fri Oct 17 2003 schwab@suse.de
- Fix a whole pile of missing declarations.
* Wed Oct 15 2003 ke@suse.de
- Update to version 0.7.5.
* Tue Aug 12 2003 adrian@suse.de
- add Categories
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Fri Jun 27 2003 ke@suse.de
- New package: version 0.5.4.
